@@ -26,7 +26,7 @@ def _download(args):
 		Downloads the json response and returns it
 	"""
 	
-	base = "http://lyricwiki.org/mw_api.php?"
+	base = "http://lyrics.wikia.com/api.php?"
 	args = urllib.urlencode(args)
 	
 	return urllib.urlopen(base + args).read()
